@@ -1,10 +1,10 @@
 package Net::DNS::RR::NSEC;
 
 #
-# $Id: NSEC.pm 1302 2015-01-23 11:07:41Z willem $
+# $Id: NSEC.pm 1307 2015-02-02 09:30:57Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1302 $)[1];
+$VERSION = (qw$LastChangedRevision: 1307 $)[1];
 
 
 use strict;
@@ -62,7 +62,7 @@ sub nxtdname {
 	my $self = shift;
 
 	$self->{nxtdname} = new Net::DNS::DomainName(shift) if scalar @_;
-	$self->{nxtdname}->name if defined wantarray;
+	$self->{nxtdname}->name if defined wantarray && $self->{nxtdname};
 }
 
 
