@@ -1,10 +1,10 @@
 package Net::DNS::RR::NSEC3PARAM;
 
 #
-# $Id: NSEC3PARAM.pm 1179 2014-03-19 21:46:58Z willem $
+# $Id: NSEC3PARAM.pm 1302 2015-01-23 11:07:41Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1179 $)[1];
+$VERSION = (qw$LastChangedRevision: 1302 $)[1];
 
 
 use strict;
@@ -18,7 +18,6 @@ Net::DNS::RR::NSEC3PARAM - DNS NSEC3PARAM resource record
 
 
 use integer;
-
 use warnings;
 
 
@@ -54,7 +53,8 @@ sub parse_rdata {			## populate RR from rdata in argument list
 	$self->algorithm(shift);
 	$self->flags(shift);
 	$self->iterations(shift);
-	$self->salt(shift);
+	my $salt = shift;
+	$self->salt($salt) unless $salt eq '-';
 }
 
 
@@ -100,10 +100,8 @@ sub saltbin {
 
 ########################################
 
-
 sub hashalgo {&algorithm}		## historical
 
-
 1;
 __END__
 
@@ -165,9 +163,9 @@ integer.  The value is between 0 and 65535, inclusive.
     $salt = $rr->salt;
     $rr->salt( $salt );
 
-The Salt field is represented as a sequence of hexadecimal digits.
-No whitespace is allowed within the sequence.  A "-" (unquoted) is
-used in string format to indicate that the salt field is absent. 
+The Salt field is represented as a contiguous sequence of hexadecimal
+digits. A "-" (unquoted) is used in string format to indicate that the
+salt field is absent. 
 
 =head2 saltbin
 
