@@ -14,10 +14,10 @@ sub UNITCHECK {				## restore %SIG after compilation
 package Net::DNS::RR::SIG;
 
 #
-# $Id: SIG.pm 1302 2015-01-23 11:07:41Z willem $
+# $Id: SIG.pm 1307 2015-02-02 09:30:57Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1302 $)[1];
+$VERSION = (qw$LastChangedRevision: 1307 $)[1];
 
 
 use strict;
@@ -145,15 +145,14 @@ sub defaults() {			## specify RR attribute default values
 
 	my %algbyval = reverse @algbyname;
 
-	my @algbynum = map { ( $_, 0 + $_ ) } keys %algbyval;	# accept algorithm number
-
-	my %algbyname = map { s /[^A-Za-z0-9]//g; $_ } @algbyname, @algbynum;
+	my @algbynum = map { ( $_, 0 + $_ ) } ( 1 .. 250, keys %algbyval );
 
+	my %algbyname = map { s/[^A-Za-z0-9]//g; $_ } @algbyname, @algbynum;
 
 	sub algbyname {
 		my $name = shift;
 		my $key	 = uc $name;				# synthetic key
-		$key =~ s /[^A-Z0-9]//g;			# strip non-alphanumerics
+		$key =~ s/[^A-Z0-9]//g;				# strip non-alphanumerics
 		return $algbyname{$key} || croak "unknown algorithm $name";
 	}
 
@@ -237,7 +236,7 @@ sub signame {
 	my $self = shift;
 
 	$self->{signame} = new Net::DNS::DomainName2535(shift) if scalar @_;
-	$self->{signame}->name if defined wantarray;
+	$self->{signame}->name if defined wantarray && $self->{signame};
 }
 
 
@@ -490,7 +489,7 @@ sub _CreateSig {
 
 	eval {
 		my $class = $SEC{$algorithm} || die "algorithm $algorithm not supported";
-		$self->sigbin( $class->generate(@_) );
+		$self->sigbin( $class->sign(@_) );
 	} || croak 'signature generation failed', $@ ? "\n\t$@" : '';
 }
 
@@ -746,8 +745,8 @@ Package template (c)2009,2012 O.M.Kolkman and R.W.Franks.
 
 L<perl>, L<Net::DNS>, L<Net::DNS::RR>, L<Net::DNS::SEC>,
 RFC4034, RFC3755, RFC2535, RFC2931, RFC3110, RFC3008,
-L<Crypt::OpenSSL::DSA>,
-L<Crypt::OpenSSL::RSA>
+L<Net::DNS::SEC::DSA>,
+L<Net::DNS::SEC::RSA>
 
 L<Algorithm Numbers|http://www.iana.org/assignments/dns-sec-alg-numbers>
 
